@@ -3,9 +3,12 @@
 from os import fstat
 import os.path
 from ZODB.POSException import POSKeyError
-from plone.app.blob.utils import openBlob
+
 from Products.CMFCore.utils import getToolByName
 
+from plone.app.blob.utils import openBlob
+from plone.app.imaging.interfaces import IImageScaleHandler
+
 def patched_field_get_size(self):
     try:
         blob = openBlob(self.blob)
@@ -34,7 +37,16 @@ def patched_field_index_html(self, instance, REQUEST=None, RESPONSE=None, dispos
         if not RESPONSE:
             RESPONSE = instance.REQUEST.RESPONSE
         putils = getToolByName(instance, 'plone_utils')
-        putils.addPortalMessage('BLOB file is missing', type='warning')
+        putils.addPortalMessage('Missing BLOB file for %s' % instance.absolute_url_path(), type='warning')
         RESPONSE.redirect(instance.absolute_url()+'/view')
 
-
+def patched_getScale(self, instance, scale=None, **kwargs):
+    if scale is None:
+        return self.getUnwrapped(instance, **kwargs)
+    handler = IImageScaleHandler(self, None)
+    if handler is not None:
+        try:
+            return handler.getScale(instance, scale)
+        except POSKeyError:
+            pass
+    return None
